# appimage-builder

*GNU/Linux packaging made easy!* ™

## What is it?

It's a tool for packing applications along with all of its dependencies using the
system package manager to obtain binaries and resolve dependencies. It creates a 
**self-sufficient** and **portable** bundle using the [AppImage](https://appimage.org)
format.

Features:
- Real GNU/Linux packaging (no more distro packaging)
- Simple recipes
- Simple workflow
- Backward and forward compatibility
- One binary, many target systems.


## Useful links

- [Installation](https://appimage-builder.readthedocs.io/en/latest/intro/install.html)
- [Getting help](https://appimage-builder.readthedocs.io/en/latest/index.html#getting-help)
- [Tutorial](https://appimage-builder.readthedocs.io/en/latest/intro/tutorial.html)
- [Documentation](https://appimage-builder.readthedocs.io)


## Projects using appimage-builder

[![Zeal](https://raw.githubusercontent.com/zealdocs/zeal/master/assets/freedesktop/128-apps-zeal.png)](https://github.com/zealdocs/zeal/)
[![Kstars](https://invent.kde.org/education/kstars/-/raw/master/logo.png)](https://invent.kde.org/education/kstars)
[![Glimpse](https://raw.githubusercontent.com/glimpse-editor/Glimpse/dev-g210/icons/Color/128/glimpse-icon.png)](https://github.com/glimpse-editor/Glimpse)
[![MystiQ](https://raw.githubusercontent.com/swl-x/MystiQ/master/icons/mystiq_128x128.png)](https://github.com/swl-x/MystiQ)
[![MAUI](https://invent.kde.org/uploads/-/system/group/avatar/1557/avatar.png?width=64)](https://invent.kde.org/maui)